@@ -1,5 +1,6 @@
-as.folder <- function(x, ..., groups = NULL)
-  UseMethod("as.folder")
+# as.folder <- function(x, ..., groups = NULL)
+as.folder <- function(x, ...)
+    UseMethod("as.folder")
 
 #as.folder.default <- function(x, ..., groups = NULL) {        
 #  # Change a data frame x into an object of class 'folder'.
